===============
Developer Guide
===============

.. toctree::
    :hidden:

    repository.rst
    build.rst
    develop.rst
    deploy.rst
    ci.rst
    licence.rst


This guide explains how Espresso works 'behind the scenes', particularly the systems 
for validation, build, documentation and deployment - the Espresso Machine:

- :doc:`repository`
- :doc:`build`
- :doc:`develop`
- :doc:`deploy`
- :doc:`ci`
- :doc:`licence`
